@@ -1,3 +1,11 @@
+from __future__ import unicode_literals
+from __future__ import print_function
+from __future__ import division
+from __future__ import absolute_import
+from future import standard_library
+standard_library.install_aliases()
+from builtins import *
+from builtins import object
 from grpc import StatusCode
 from grpc._channel import _Rendezvous
 
@@ -10,7 +18,7 @@ DEFAULT_STOP_MAX_ATTEMPT = 7
 
 
 # Retry option class
-class RetryOptions:
+class RetryOptions(object):
     def __init__(self,
                  wait_exponential_multiplier,
                  wait_exponential_max,
